<?php
namespace MyApi\Model\AppTypes;

use ExternalApi\Model\App\AbstractAppType as AbstractAppType;
use MyApi\Model\ExternalApi\MyBrand\Get as MyBrandGet;

/**
* Наше тестовое приложение
*/
class MyCustomApp extends AbstractAppType
{
    /**
    * Возвращает строковый идентификатор приложения
    * 
    * @return string
    */
    public function getId()
    {
        return 'my-custom-app'; //Любой ID, который будет характеризовать ваше приложение
    }
    
    /**
    * Проверяет SHA1 от секретного ключа client_secret, который должен
    * передаваться вместе с client_id в момент авторизации
    *
    * @param string $client_secret - секретное слово на клиентской стороне
    * @return string
    */
    public function checkSecret($client_secret)
    {
        //Ожидаем в client_secret пароль: password123, sha1('password123') = cbfdac6008f9cab4083784cbd1874f76618d2a97
        //Не храним в коде приложения пароль в открытом виде.
        return sha1( $client_secret ) == 'cbfdac6008f9cab4083784cbd1874f76618d2a97';
    }
    
    /**
    * Метод возвращает название приложения
    * 
    * @return string
    */
    public function getTitle()
    {
        return t('Наше тестовое мобильное приложение');
    }
    
    /**
    * Метод возвращает массив, содержащий требуемые права доступа к методам API для приложения
    * 
    * @return array
     * [
    *       'метод1' => код действия,
    *       'метод2' => [код действия, код действия, ...]
    *   ...
    * ]
    */
    public function getAppRights()
    {
        return [
            'mybrand.getList'  => self::FULL_RIGHTS, //Полные права. Права будет проверяться внутри метода в вашей функции.
            'mybrand.get'  => MyBrandGet::RIGHT_READ,
        ];
    }

    /**
    * Авторизация будет проходить только, если пользователь будет
    * принадлежать группам, которых вернет данный метод.
    * 
    * @return array
    * ["group_id_1", "group_id_2", ...]
    */    
    public function getAllowUserGroup()
    {
        return ['admins']; //Пользователь должен будет принадлежать группе Администраторы
    }

}